@@ -20,6 +20,7 @@ ginv <- function(X, tol = sqrt(.Machine$double.eps))
     Xsvd <- svd(X)
     if(is.complex(X)) Xsvd$u <- Conj(Xsvd$u)
     Positive <- Xsvd$d > max(tol * Xsvd$d[1], 0)
-    if(!any(Positive)) array(0, dim(X)[2:1])
-    else Xsvd$v[, Positive] %*% ((1/Xsvd$d[Positive]) * t(Xsvd$u[, Positive]))
+    if (all(Positive)) Xsvd$v %*% (1/Xsvd$d * t(Xsvd$u))
+    else if(!any(Positive)) array(0, dim(X)[2:1])
+    else Xsvd$v[, Positive, drop=FALSE] %*% ((1/Xsvd$d[Positive]) * t(Xsvd$u[, Positive, drop=FALSE]))
 }
